#!/bin/sh

build_name="bridge-build"

if [ ! -f ecosystem.config.js ]; then
   echo "
   ecosystem.config.js is not found.
   Stopping installation process.
   "
   exit
fi

# INSTALL DEPENDENCIES
sudo apt update
sudo apt upgrade -y


if ! ifconfig > /dev/null; then
   sudo apt-get install net-tools -y || exit
fi


# SET BRIDGE IP CONFIG FOR ARMBIAN IF ETHERNET CABLE IS PLUGGED IN

if cat /etc/armbian-release > /dev/null; then

   if ifconfig eth0 2> /dev/null | grep netmask; then
      gateway=$(ip route | grep default | head -1 | cut -d" " -f3)
      network_data=$(ifconfig eth0 | grep netmask)
      ip=$(echo "${network_data}" | cut -d" " -f10)
      netmask=$(echo "${network_data}" | cut -d" " -f13)

      config="
source /etc/network/interfaces.d/*
# Network is managed by Network manager
auto lo
iface lo inet loopback

# The primary network interface
# allow-hotplug eth0
# iface eth0 inet dhcp
 
# Static IP address
auto eth0      # ou auto enp0s7 (see  ifconfig)
iface eth0 inet static
        address ${ip}
        netmask ${netmask}
        gateway ${gateway}   
"

      if [ ! -f "/etc/network/interfaces" ]; then
         touch "/etc/network/interfaces" && echo "${config}" > /etc/network/interfaces
         echo "Network configuration file is created and available in /etc/network/interfaces"
      fi
   fi
fi

if ! git --version 2> /dev/null; then
   echo "Git is not installed. Installing..."
   sudo apt-get install git -y || exit
fi

if ! ffmpeg -version 2> /dev/null | grep "version"; then
   echo "FFmpeg is not installed. Installing..."
   sudo apt install ffmpeg -y || exit
   
   ffmpeg_version=$(ffmpeg -version | head -1 | cut -d' ' -f3 | cut -d'.' -f1)

   if grep -q "FFMPEG_VERSION:" ./ecosystem.config.js; then
       sed -i "s/\(FFMPEG_VERSION:\).*/\1 ${ffmpeg_version},/" ./ecosystem.config.js
   else
       sed -i "/env:/a\ \ \ \ \ \ \ \ FFMPEG_VERSION: ${ffmpeg_version}," ./ecosystem.config.js
   fi

fi

if ! node -v 2> /dev/null; then
   echo "Node is not installed. Installing..."
   curl -o- https://raw.githubusercontent.com/nvm-sh/nvm/v0.39.1/install.sh | bash
   
   export NVM_DIR="$HOME/.nvm"
   [ -s "$NVM_DIR/nvm.sh" ] && \. "$NVM_DIR/nvm.sh"  # This loads nvm
   [ -s "$NVM_DIR/bash_completion" ] && \. "$NVM_DIR/bash_completion"  # This loads nvm bash_completion

   nvm install lts/hydrogen
   npm install -g pm2
   pm2 startup
fi

# PULL BUILD
if [ ! -d "${PWD}/${build_name}" ]; then
   git clone https://github.com/vcloud-ai/${build_name}.git || exit
fi

if [ ! -f "${PWD}/${build_name}/ecosystem.config.js" ]; then
   cp "./ecosystem.config.js" "./${build_name}/ecosystem.config.js"
fi

cd "./${build_name}"

# LAUNCH
if pm2 list | grep finder > /dev/null; then
   echo "Bridge is already running by PM2. Restarting app..."
   pm2 delete finder > /dev/null
fi

set_free_port() {
    port=8000
    while netstat -tulpn | egrep ":${port} "; do
    	(( port ++ ))
    done
    
    sed -i "s/\? [0-9]\{1,5\} :/\? ${port} :/g" ./init.js
    sed -i "s/-p [0-9]\{1,5\}/-p ${port}/g" ./package.json

    echo "Using port ${port}"
}

if netstat -tulpn | grep ":80 "; then
   echo "Port 80 is already used by another process"
   set_free_port
else
    sed -i "s/\? [0-9]\{1,5\} :/\? 80 :/g" ./init.js
    sed -i "s/-p [0-9]\{1,5\}/-p 80/g" ./package.json
fi

pm2 start ecosystem.config.js
pm2 save

echo "
===========================================
===== Bridge is successfully launched =====
===========================================
"
